jaclearn.dataflow.dataflow
==========================

.. automodule:: jaclearn.dataflow.dataflow

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AdvancedDataFlowBase
      DataFlowBase
      ProxyDataFlowBase
      RandomizedDataFlowBase
      SimpleDataFlowBase
   
   

   
   
   

   
   
   








.. rubric:: Class AdvancedDataFlowBase
.. autoclass:: AdvancedDataFlowBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DataFlowBase
.. autoclass:: DataFlowBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ProxyDataFlowBase
.. autoclass:: ProxyDataFlowBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomizedDataFlowBase
.. autoclass:: RandomizedDataFlowBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SimpleDataFlowBase
.. autoclass:: SimpleDataFlowBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







